ReprSerde

Derive Macro ReprSerde 

#[derive(ReprSerde)]
Derives Serialize and Deserialize by reading discriminant values directly from the AST.

The enum must have exactly one data-carrying variant (e.g. Unknown(u8)) which is used as the fallback for unknown values.